@@ -419,6 +419,8 @@ def ths_stock_concept(code):
         logger.error("获取详情异常:{},异常信息:{}", code, e)
 
 
+# HK市场 https://basic.10jqka.com.cn/mobile/HK1456/profile.html  https://basic.10jqka.com.cn/mobile/HK1456/company.html
+# https://basic.10jqka.com.cn/astockph/briefinfo/index.html?showhead=0&fromshare=1&code=300430&marketid=33&client_userid=ESgcM&back_source=hyperlink&share_hxapp=isc&fontzoom=no#/company/ziliao
 def get_company_info_detail(symbol: str = "305794") -> pd.DataFrame:
     try:
         url = f'https://basic.10jqka.com.cn/basicapi/company_info/merge_info/v1/base_info/?code={symbol}&market=33&type=stock'
@@ -838,6 +840,7 @@ def get_concept_index():
 
 
 if __name__ == '__main__':
+    re = wei_cai_api('603619 支撑压力位', 'stock')
     df = get_symbol_add_new_concept('600128')
     print(df)
     # while True:
