@@ -10,5 +10,11 @@ sys.path.append(project_path)
 SELF_CHOOSE_THS_CONCEPT = 'ths_concept'
 # 同花顺行业
 SELF_CHOOSE_THS_INDUSTRY = 'ths_industry'
-# 开盘啦概念
+
 SELF_CHOOSE_KPL_CONCEPT = 'kpl_concept'
+
+# 开盘啦一级概念
+SELF_CHOOSE_KPL_FIRST_CONCEPT = 'kpl_first_concept'
+
+# 开盘啦二级概念
+SELF_CHOOSE_KPL_SECOND_CONCEPT = 'kpl_second_concept'
